==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/loaders/statistical/GenerateConstants.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.statistical;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;

import org.eclipse.hyades.loaders.util.LoadersUtils;
import org.eclipse.hyades.loaders.util.LookupService;

/**
 * @author slavescu
 */
public class GenerateConstants {
	//~ Static fields/initializers -----------------------------------------------------------------

	private static Class[] classes =
		{ 
			StatisticalXMLLoadersFactory.class, 
			XMLDescriptorLoader.class, 
			XMLSampleDescriptorLoader.class,
			XMLCounterDescriptorLoader.class,
			XMLDiscreteObservationLoader.class,
			XMLContiguousObservationLoader.class,
			XMLTextObservationLoader.class,
			SnapshotObservationBase.class
	};
	private static Class[] lookUpServiceClasses =
		{
			StatisticalLookupService.class
		};

	//~ Methods ------------------------------------------------------------------------------------

	public static void main(String[] args) {
		GenerateConstants generateConstants = new GenerateConstants();
		generateConstants.processClasses();
	}

	private void processClasses() {
		List list = new ArrayList();

		for (int i = 0; i < classes.length; i++) {
			addFieldsName(classes[i], list);
		}

		for (int i = 0; i < lookUpServiceClasses.length; i++) {
			addLookUpServiceName(lookUpServiceClasses[i], list);
		}


		Collections.sort(list,new Comparator(){
			/**
			 *
			 */

			public int compare(Object o1, Object o2) {
				return ((String[])o1)[0].compareTo(((String[])o2)[0]);
			}

		});

		//		System.out.println("// "+ theClass.getName() +" related constants");
		String prevName = "";
		PrintWriter out;
		try {
			out =
				new PrintWriter(
					new FileWriter("E:/test/workspaces/defects/hyades-cvs/org.eclipse.hyades.models.statistical/src/org/eclipse/hyades/loders/statistical/StatisticalConstants.java"));
			out.println(
				"/**********************************************************************\n"
					+ " * Copyright (c) 2003 Hyades project.\n"
					+ " * All rights reserved.   This program and the accompanying materials\n"
					+ " * are made available under the terms of the Common Public License v0.5\n"
					+ " * which accompanies this distribution, and is available at\n"
					+ " * http://www.eclipse.org/legal/cpl-v05.html\n"
					+ " *\n"
					+ " * Contributors:\n"
					+ " * IBM - Initial API and implementation\n"
					+ " **********************************************************************/\n"
					+ "package org.eclipse.hyades.loaders.statistical;\n"
					+ "\n"
					+ "/**\n"
					+ " * @author slavescu\n"
					+ " */\n"
					+ "public class StatisticalConstants {\n");

			for (Iterator iter = list.iterator(); iter.hasNext();) {
				String[] field = (String[]) iter.next();

//				if (!field[0].equals(prevName)) {
				
					out.println(
						"\tprotected static final int "
							+ field[0]
							+ "_int = "
							+ LoadersUtils.getHashCode(field[1])
							+ ";");
//					prevName = field[0];
//				}
			}
			out.println("}\n");
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	private void addLookUpServiceName(Class class1, List list) {
		try {
			LookupService lookupService = (LookupService)class1.newInstance();
			for (Iterator iter = lookupService.getSupportedTypes().iterator(); iter.hasNext();) {
				Class element = (Class) iter.next();
				String name = element.getName();
//				name = name.replace('.','_');
				if(name.lastIndexOf('.')>0)
					name = name.substring(name.lastIndexOf('.')+1); 
				list.add(new String[]{name,element.getName()});
			}
		} catch (InstantiationException e) {
			e.printStackTrace();
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		}
		
	}

	private void addFieldsName(Class theClass, List list) {

		try {
			Field[] fields = theClass.getDeclaredFields();
			for (int i = 0; i < fields.length; i++) {
				int mod = fields[i].getModifiers();
				if (Modifier.isProtected(mod) && Modifier.isStatic(mod) && Modifier.isFinal(mod) && fields[i].getType()==String.class)
				{
					Object value = fields[i].get(null);
					if(value!=null)
						list.add(new String[]{fields[i].getName(),value.toString()});
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/loaders/statistical/GenerateConstants.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: GenerateConstants.java,v 1.5 2005/02/16 22:21:26 qiyanli Exp $
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.statistical;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import org.eclipse.hyades.loaders.util.LoadersUtils;
import org.eclipse.hyades.loaders.util.LookupService;

/**
 * @author slavescu
 */
public class GenerateConstants {
	//~ Static fields/initializers -----------------------------------------------------------------

	private static Class[] classes =
		{ 
			StatisticalXMLLoadersFactory.class, 
			XMLDescriptorLoader.class, 
			XMLSampleDescriptorLoader.class,
			XMLCounterDescriptorLoader.class,
			XMLDiscreteObservationLoader.class,
			XMLContiguousObservationLoader.class,
			XMLTextObservationLoader.class,
			SnapshotObservationBase.class
	};
	private static Class[] lookUpServiceClasses =
		{
			StatisticalLookupService.class
		};

	//~ Methods ------------------------------------------------------------------------------------

	public static void main(String[] args) {
		GenerateConstants generateConstants = new GenerateConstants();
		generateConstants.processClasses();
	}

	private void processClasses() {
		List list = new ArrayList();

		for (int i = 0; i < classes.length; i++) {
			addFieldsName(classes[i], list);
		}

		for (int i = 0; i < lookUpServiceClasses.length; i++) {
			addLookUpServiceName(lookUpServiceClasses[i], list);
		}


		Collections.sort(list,new Comparator(){
			/**
			 *
			 */

			public int compare(Object o1, Object o2) {
				return ((String[])o1)[0].compareTo(((String[])o2)[0]);
			}

		});

		//		System.out.println("// "+ theClass.getName() +" related constants");
		String prevName = "";
		PrintWriter out;
		try {
			out =
				new PrintWriter(
					new FileWriter("E:/test/workspaces/defects/hyades-cvs/org.eclipse.hyades.models.statistical/src/org/eclipse/hyades/loders/statistical/StatisticalConstants.java"));
			out.println(
				"/**********************************************************************\n"
					+ " * Copyright (c) 2003 Hyades project.\n"
					+ " * All rights reserved.   This program and the accompanying materials\n"
					+ " * are made available under the terms of the Common Public License v0.5\n"
					+ " * which accompanies this distribution, and is available at\n"
					+ " * http://www.eclipse.org/legal/cpl-v05.html\n"
					+ " *\n"
					+ " * Contributors:\n"
					+ " * IBM - Initial API and implementation\n"
					+ " **********************************************************************/\n"
					+ "package org.eclipse.hyades.loaders.statistical;\n"
					+ "\n"
					+ "/**\n"
					+ " * @author slavescu\n"
					+ " */\n"
					+ "public class StatisticalConstants {\n");

			for (Iterator iter = list.iterator(); iter.hasNext();) {
				String[] field = (String[]) iter.next();

//				if (!field[0].equals(prevName)) {
				
					out.println(
						"\tprotected static final int "
							+ field[0]
							+ "_int = "
							+ LoadersUtils.getHashCode(field[1])
							+ ";");
//					prevName = field[0];
//				}
			}
			out.println("}\n");
			out.close();
		} catch (IOException e) {
			LoadersUtils.log(e);
		}
	}

	private void addLookUpServiceName(Class class1, List list) {
		try {
			LookupService lookupService = (LookupService)class1.newInstance();
			for (Iterator iter = lookupService.getSupportedTypes().iterator(); iter.hasNext();) {
				Class element = (Class) iter.next();
				String name = element.getName();
//				name = name.replace('.','_');
				if(name.lastIndexOf('.')>0)
					name = name.substring(name.lastIndexOf('.')+1); 
				list.add(new String[]{name,element.getName()});
			}
		} catch (InstantiationException e) {
			LoadersUtils.log(e);
		} catch (IllegalAccessException e) {
			LoadersUtils.log(e);
		}
		
	}

	private void addFieldsName(Class theClass, List list) {

		try {
			Field[] fields = theClass.getDeclaredFields();
			for (int i = 0; i < fields.length; i++) {
				int mod = fields[i].getModifiers();
				if (Modifier.isProtected(mod) && Modifier.isStatic(mod) && Modifier.isFinal(mod) && fields[i].getType()==String.class)
				{
					Object value = fields[i].get(null);
					if(value!=null)
						list.add(new String[]{fields[i].getName(),value.toString()});
				}
			}
		} catch (Exception e) {
			LoadersUtils.log(e);
		}
	}
}
